==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/base/test-standard/src/test/java/org/openscience/cdk/qsar/result/IntegerResultTest.java <==
/* Copyright (C) 2007  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.qsar.result;

import org.junit.Assert;
import org.junit.Test;
import org.openscience.cdk.test.CDKTestCase;

/**
 * @cdk.module test-standard
 */
public class IntegerResultTest extends CDKTestCase {

    public IntegerResultTest() {
        super();
    }

    @Test
    public void testIntegerResult_int() {
        IntegerResult result = new IntegerResult(5);
        Assert.assertNotNull(result);
    }

    @Test
    public void testToString() {
        IntegerResult result = new IntegerResult(5);
        Assert.assertEquals("5", result.toString());
    }

    @Test
    public void testIntValue() {
        IntegerResult result = new IntegerResult(5);
        Assert.assertEquals(5, result.intValue());
    }

    @Test
    public void testLength() {
        IntegerResult result = new IntegerResult(5);
        Assert.assertEquals(1, result.length());
    }
}

==> cdk_2.9.orig.tar.gz: cdk-cdk-2.9/base/test-standard/src/test/java/org/openscience/cdk/qsar/result/IntegerResultTest.java <==
/* Copyright (C) 2007  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.qsar.result;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.openscience.cdk.test.CDKTestCase;

/**
 * @cdk.module test-standard
 */
class IntegerResultTest extends CDKTestCase {

    IntegerResultTest() {
        super();
    }

    @Test
    void testIntegerResult_int() {
        IntegerResult result = new IntegerResult(5);
        Assertions.assertNotNull(result);
    }

    @Test
    void testToString() {
        IntegerResult result = new IntegerResult(5);
        Assertions.assertEquals("5", result.toString());
    }

    @Test
    void testIntValue() {
        IntegerResult result = new IntegerResult(5);
        Assertions.assertEquals(5, result.intValue());
    }

    @Test
    void testLength() {
        IntegerResult result = new IntegerResult(5);
        Assertions.assertEquals(1, result.length());
    }
}
